@@ -3,7 +3,7 @@ use strict;
 use warnings;
 
 package JSON::Path;
-
+$JSON::Path::VERSION = '0.301';
 # VERSION
 
 use Exporter::Tiny ();
@@ -133,13 +133,13 @@ sub map {
 BEGIN {
 
     package JSON::Path::Helper;
-
-    use 5.008;
+$JSON::Path::Helper::VERSION = '0.301';
+use 5.008;
     use strict qw(vars refs);
     no warnings;
 
-    our $AUTHORITY = 'cpan:TOBYINK';
-    our $VERSION   = '0.205';
+    our $AUTHORITY = 'cpan:POPEFELIX';
+    # VERSION
 
     use Carp;
     use Scalar::Util qw[blessed];
@@ -375,7 +375,7 @@ JSON::Path
 
 =head1 VERSION
 
-version 0.300
+version 0.301
 
 =head1 SYNOPSIS
 
